yakumo.neutron.v2.subnet_pool

Package yakumo :: Package neutron :: Package v2 :: Module subnet_pool |
[hide private]
[frames] | no frames]

# Module subnet_pool

source code

Resource class and its manager for subnet pools in Compute API v2

Classes | [hide private]
| Resource Resource class for subnet pools in Compute API v2
| Manager Manager class for subnet pools in Compute API v2

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.neutron.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('prefixes'
      , 'prefixes', mapper.Noop), ('ip_version', 'ip_version', mapper.Noop),
       ('min_prefixlen', 'min_prefixlen', mapper.Noop), ('default_prefixlen'
      , 'default_prefixlen', mapper.Noop), ('max_prefixlen', 'max_prefixlen'
      , mapper.Noop), ('default_quota', 'default_quota', mapper.Noop), ('is_
      shared', 'shared', mapper.Noop,), ('address_scope_id', 'address_scope_
      id', mapper.Noop), ('project', 'tenant_id', mapper.Resource('project')
      ),]